==> jc-1.4.0.tar.gz: polyglot/types/reflect/InnerClasses.h <==
// class polyglot.types.reflect.InnerClasses

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d931fb91b452174 polyglot_types_reflect_Attribute
// @dep_class 9ef272f75aa753c2 polyglot_types_reflect_InnerClasses

// header file dependencies
// @dep_header polyglot_types_reflect_Attribute

#include "polyglot/types/reflect/Attribute.h"

#ifndef _JC_polyglot_types_reflect_InnerClasses_H_
#define _JC_polyglot_types_reflect_InnerClasses_H_

// Forward structure declarations
struct _jc_java_io_DataInputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_InnerClasses$sub_refs	_jc_polyglot_types_reflect_InnerClasses$sub_refs;
typedef struct _jc_polyglot_types_reflect_InnerClasses$sub_nonrefs	_jc_polyglot_types_reflect_InnerClasses$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_InnerClasses$refs	_jc_polyglot_types_reflect_InnerClasses$refs;
typedef struct _jc_polyglot_types_reflect_InnerClasses$nonrefs	_jc_polyglot_types_reflect_InnerClasses$nonrefs;
typedef struct _jc_polyglot_types_reflect_InnerClasses$object	_jc_polyglot_types_reflect_InnerClasses$object;

typedef const struct _jc_polyglot_types_reflect_InnerClasses$vmethods	_jc_polyglot_types_reflect_InnerClasses$vmethods;
typedef const struct _jc_polyglot_types_reflect_InnerClasses$vtable	_jc_polyglot_types_reflect_InnerClasses$vtable;
typedef const struct _jc_polyglot_types_reflect_InnerClasses$vtype	_jc_polyglot_types_reflect_InnerClasses$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_InnerClasses$method$_init$f7ce785ea6b7867d(_jc_env *, struct _jc_polyglot_types_reflect_InnerClasses$object *, struct _jc_java_io_DataInputStream$object *, jint, jint);

// Virtual methods structure
struct _jc_polyglot_types_reflect_InnerClasses$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_InnerClasses$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Attribute$vmethods	polyglot_types_reflect_Attribute;
	_jc_polyglot_types_reflect_InnerClasses$vmethods	polyglot_types_reflect_InnerClasses;
};

// Vtype
struct _jc_polyglot_types_reflect_InnerClasses$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_InnerClasses$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_InnerClasses$sub_refs {
	_jc_object_array	*classes;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_InnerClasses$refs {
    _jc_polyglot_types_reflect_InnerClasses$sub_refs	polyglot_types_reflect_InnerClasses;
    _jc_polyglot_types_reflect_Attribute$sub_refs	polyglot_types_reflect_Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_InnerClasses$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_InnerClasses$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Attribute$sub_nonrefs	polyglot_types_reflect_Attribute;
    _jc_polyglot_types_reflect_InnerClasses$sub_nonrefs	polyglot_types_reflect_InnerClasses;
};

// Object instance structure
struct _jc_polyglot_types_reflect_InnerClasses$object {
	_jc_polyglot_types_reflect_InnerClasses$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_InnerClasses$vtype	*vtype;
	_jc_polyglot_types_reflect_InnerClasses$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_InnerClasses$vtype _jc_polyglot_types_reflect_InnerClasses$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_InnerClasses, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_InnerClasses$class_object;

#endif	/* _JC_polyglot_types_reflect_InnerClasses_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/reflect/InnerClasses.h <==
// class polyglot.types.reflect.InnerClasses

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d931fb91b452174 polyglot_types_reflect_Attribute
// @dep_class 9ef272f75aa753c2 polyglot_types_reflect_InnerClasses

// header file dependencies
// @dep_header polyglot_types_reflect_Attribute

#include "polyglot/types/reflect/Attribute.h"

#ifndef _JC_polyglot_types_reflect_InnerClasses_H_
#define _JC_polyglot_types_reflect_InnerClasses_H_

// Forward structure declarations
struct _jc_java_io_DataInputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_InnerClasses$sub_refs	_jc_polyglot_types_reflect_InnerClasses$sub_refs;
typedef struct _jc_polyglot_types_reflect_InnerClasses$sub_nonrefs	_jc_polyglot_types_reflect_InnerClasses$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_InnerClasses$refs	_jc_polyglot_types_reflect_InnerClasses$refs;
typedef struct _jc_polyglot_types_reflect_InnerClasses$nonrefs	_jc_polyglot_types_reflect_InnerClasses$nonrefs;
typedef struct _jc_polyglot_types_reflect_InnerClasses$object	_jc_polyglot_types_reflect_InnerClasses$object;

typedef const struct _jc_polyglot_types_reflect_InnerClasses$vmethods	_jc_polyglot_types_reflect_InnerClasses$vmethods;
typedef const struct _jc_polyglot_types_reflect_InnerClasses$vtable	_jc_polyglot_types_reflect_InnerClasses$vtable;
typedef const struct _jc_polyglot_types_reflect_InnerClasses$vtype	_jc_polyglot_types_reflect_InnerClasses$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_InnerClasses$method$_init$f7ce785ea6b7867d(_jc_env *, struct _jc_polyglot_types_reflect_InnerClasses$object *, struct _jc_java_io_DataInputStream$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_reflect_InnerClasses$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_InnerClasses$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Attribute$vmethods	polyglot_types_reflect_Attribute;
	_jc_polyglot_types_reflect_InnerClasses$vmethods	polyglot_types_reflect_InnerClasses;
};

// Vtype
struct _jc_polyglot_types_reflect_InnerClasses$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_InnerClasses$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_InnerClasses$sub_refs {
	_jc_object_array	*classes;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_InnerClasses$refs {
    _jc_polyglot_types_reflect_InnerClasses$sub_refs	polyglot_types_reflect_InnerClasses;
    _jc_polyglot_types_reflect_Attribute$sub_refs	polyglot_types_reflect_Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_InnerClasses$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_InnerClasses$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Attribute$sub_nonrefs	polyglot_types_reflect_Attribute;
    _jc_polyglot_types_reflect_InnerClasses$sub_nonrefs	polyglot_types_reflect_InnerClasses;
};

// Object instance structure
struct _jc_polyglot_types_reflect_InnerClasses$object {
	_jc_polyglot_types_reflect_InnerClasses$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_InnerClasses$vtype	*vtype;
	_jc_polyglot_types_reflect_InnerClasses$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_InnerClasses$vtype _jc_polyglot_types_reflect_InnerClasses$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_InnerClasses, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_InnerClasses$class_object;

#endif	/* _JC_polyglot_types_reflect_InnerClasses_H_ */
